RDFFormats.Store.AbstractHandler

Package RDFFormats :: Module Store :: Class AbstractHandler |
[show private | hide private]
[frames | no frames]

## Class AbstractHandler

Known Subclasses:
  `Store`

    WebOrganiser-compatible handler methods.

Method Summary
| `get_supported_item_types(self)`
| `get_urirefs_for_attribute(self, attribute)`
| `get_urirefs_for_item_type(self, item_type_name)`
| `get_urirefs_for_property_type(self, property_type_name)`
| `parse(self, f, name, uriref)`
| `parse_document_fragment(self, doc, root, uriref)`
| `remove_node(self, node)`
| `supports_item_type(self, item_type_str)`
| `write_to_document(self, doc, root, main_node, nodes, qualifier, value_as_attribute)`
| `write_to_stream(self, stream, main_node, nodes, *args, **kw)`

Generated by Epydoc 2.1 on Mon Mar 19 01:08:11 2007 | http://epydoc.sf.net